/* xkeycaps, Copyright (c) 1994 Jamie Zawinski <jwz@netscape.com>
 *
 * This file describes the key surfaces of the Takaoka Xmint X Terminal.
 * By Christian Goetze <c-goetze@u-aizu.ac.jp>
 */

static const struct key_strings xmint_caps [] = {

 /* Row 0 */

 {"","F1",0}, {"","F2",0}, {"","F3",0}, {"","F4",0}, {"","F5",0},
 {"","F6",0}, {"","F7",0}, {"","F8",0}, {"","F9",0}, {"","F10",0},
 {"LeftArrow", "F11",0}, {"DownArrow", "F12",0},
 {"UpArrow",   "F13",0}, {"RightArrow","F14",0},  {"Back", "Space",0},

 /* Row 2 */

 {"Esc", 0},
 {"!", "1", 0}, {"@", "2", 0}, {"#", "3", 0}, {"$", "4", 0}, {"%", "5", 0},
 {"^", "6", 0}, {"&", "7", 0}, {"*", "8", 0}, {"(", "9", 0}, {")", "0", 0},
 {"_", "-", 0}, {"+", "=", 0}, {"|", "\\", 0}, {"`",  "~", 0},

 /* Row 3 */
 {"Tab",0},{"Q", 0}, {"W", 0}, {"E", 0}, {"R", 0}, {"T", 0}, {"Y", 0},
 {"U", 0}, {"I", 0}, {"O", 0}, {"P", 0}, {"{", 0}, {"}", 0}, {"Del",0},

 /* Row 4 */

 {"Ctrl", 0}, {"A", 0}, {"S", 0}, {"D", 0}, {"F", 0}, {"G", 0}, {"H", 0},
 {"J", 0}, {"K", 0}, {"L", 0}, {":", ";", 0}, {"\"", "'", 0}, /*"*/
 {"Return", 0},

 /* Row 5 */

 {"Shift", 0},  {"Z", 0}, {"X", 0}, {"C", 0}, {"V", 0}, {"B", 0}, {"N", 0},
 {"M", 0}, {"<", ",", 0}, {">", ".", 0}, {"?", "/", 0}, {"Shift", 0},
 {"Line", "Feed", 0},

 /* Row 6 */

 {"Caps", 0}, {"Star", 0}, {"L-Meta", 0},
 {  " ", 0},
 {"R-Meta", 0}, {"Alt", 0}, {"Kana", 0}
};

